==> spip_4.0.4.orig.tar.xz: plugins-dist/dump/lang/dump_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=gl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Restaurar a base',

	// I
	'info_restauration_sauvegarde' => 'Restauración da copia de seguridade @archive@',
	'info_sauvegarde' => 'Copia de seguridade',
	'info_sauvegarde_reussi_02' => 'A base foi gardada en @archive@. Pode ',
	'info_sauvegarde_reussi_03' => 'volver á xestión',
	'info_sauvegarde_reussi_04' => 'do seu web.',

	// T
	'texte_admin_tech_01' => 'Esta opción permite gardar o contido da base nun ficheiro que será almaceado no directorio @dossier@. Non esqueza tamén gardar o directorio @img@ íntegro, que é o que contén as imaxes e os documentos anexos empregados nos artigos e nas seccións.',
	'texte_admin_tech_02' => 'Atención!: esta copia de seguridade SÓ poderá ser restaurada  nun web que teña instalada a MESMA versión de SPIP. Daquela de ningunha maneira é conveniente « baleirar a base » coa esperanza de reinstalar a copia de seguridade logo da actualización...Consulte
  <a href="@spipnet@">a documentación de SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar o contido dunha copia de seguridade da base',
	'texte_restaurer_sauvegarde' => 'Esta opción permite restaurar unha copia de seguridade precedente
  feita da base. Para isto, o ficheiro da copia de seguridade ten que
  estar no cartafol @dossier@.
  Sexa prudente con esta funcionalidade : <b>as modificacións e perdas eventuais, son
  irreversíbeis.</b>', # MODIF
	'texte_sauvegarde' => 'Gardar o contido da base',
	'texte_sauvegarde_base' => 'Gardar a base'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=gl
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Restaurar a base',

	// I
	'info_restauration_sauvegarde' => 'Restauración da copia de seguridade @archive@',
	'info_sauvegarde' => 'Copia de seguridade',
	'info_sauvegarde_reussi_02' => 'A base foi gardada en @archive@. Pode ',
	'info_sauvegarde_reussi_03' => 'volver á xestión',
	'info_sauvegarde_reussi_04' => 'do seu web.',

	// T
	'texte_admin_tech_01' => 'Esta opción permite gardar o contido da base nun ficheiro que será almaceado no directorio @dossier@. Non esqueza tamén gardar o directorio @img@ íntegro, que é o que contén as imaxes e os documentos anexos empregados nos artigos e nas seccións.',
	'texte_admin_tech_02' => 'Atención!: esta copia de seguridade SÓ poderá ser restaurada  nun web que teña instalada a MESMA versión de SPIP. Daquela de ningunha maneira é conveniente « baleirar a base » coa esperanza de reinstalar a copia de seguridade logo da actualización...Consulte
  <a href="@spipnet@">a documentación de SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar o contido dunha copia de seguridade da base',
	'texte_restaurer_sauvegarde' => 'Esta opción permite restaurar unha copia de seguridade precedente
  feita da base. Para isto, o ficheiro da copia de seguridade ten que
  estar no cartafol @dossier@.
  Sexa prudente con esta funcionalidade : <b>as modificacións e perdas eventuais, son
  irreversíbeis.</b>', # MODIF
	'texte_sauvegarde' => 'Gardar o contido da base',
	'texte_sauvegarde_base' => 'Gardar a base',
];
